@@ -66,6 +66,8 @@ class RemoteFsClient(object):
         """Return a string that represents hash of base_str
         (in a hex format).
         """
+        if isinstance(base_str, six.text_type):
+            base_str = base_str.encode('utf-8')
         return hashlib.md5(base_str).hexdigest()
 
     def get_mount_point(self, device_name):
